@@ -2,17 +2,19 @@ import { Node } from "domhandler";
 import { isTag, isCDATA, isText, hasChildren } from "./tagtypes";
 import renderHTML, { DomSerializerOptions } from "dom-serializer";
 
-export const getOuterHTML: (
+export function getOuterHTML(
     node: Node | Node[],
     options?: DomSerializerOptions
-) => string = renderHTML;
+): string {
+    return renderHTML(node, options);
+}
 
 export function getInnerHTML(
     node: Node,
     options?: DomSerializerOptions
 ): string {
     return hasChildren(node)
-        ? node.children.map(node => getOuterHTML(node, options)).join("")
+        ? node.children.map((node) => getOuterHTML(node, options)).join("")
         : "";
 }
 
