@@ -1,8 +1,7 @@
 import { Node, Element } from "domhandler";
 
-export function getChildren(elem: Node): Node[] | null {
-    // @ts-ignore
-    return elem.children || null;
+export function getChildren(elem: Node | Element): Node[] | null {
+    return (elem as { children?: Node[] }).children || null;
 }
 
 export function getParent(elem: Node): Node | null {
@@ -15,17 +14,21 @@ export function getSiblings(elem: Node): Node[] | null {
 }
 
 export function getAttributeValue(elem: Element, name: string): string {
-    return elem.attribs && elem.attribs[name];
+    return elem.attribs?.[name];
 }
 
 export function hasAttrib(elem: Element, name: string): boolean {
-    return !!getAttributeValue(elem, name);
+    return (
+        !!elem.attribs &&
+        Object.prototype.hasOwnProperty.call(elem.attribs, name) &&
+        elem.attribs[name] != null
+    );
 }
 
 /***
  * Returns the name property of an element
  *
- * @argument elem The element to get the name for
+ * @param elem The element to get the name for
  */
 export function getName(elem: Element): string {
     return elem.name;
